Python Module Index — WORC 2.1.1 documentation

# Python Module Index

w

| w |
| `WORC` |
| `WORC.addexceptions` |
| `WORC.IOparser` |
| `WORC.IOparser.config_preprocessing` |
| `WORC.IOparser.config_segmentix` |
| `WORC.IOparser.config_WORC` |
| `WORC.processing` |
| `WORC.processing.classes` |
| `WORC.processing.ExtractNLargestBlobsn` |
| `WORC.processing.RTStructReader` |
| `WORC.tools` |
| `WORC.tools.Elastix` |
| `WORC.tools.Evaluate` |
| `WORC.tools.Transformix` |
| `WORC.WORC` |